<?php
/**
 * fPhotography functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @subpackage fPhotography
 * @author tishonator
 * @since fPhotography 1.0.0
 *
 */

/**
 * Set a constant that holds the theme's minimum supported PHP version.
 */
define( 'FPHOTOGRAPHY_MIN_PHP_VERSION', '5.6' );

/**
 * Immediately after theme switch is fired we we want to check php version and
 * revert to previously active theme if version is below our minimum.
 */
add_action( 'after_switch_theme', 'fphotography_test_for_min_php' );

/**
 * Switches back to the previous theme if the minimum PHP version is not met.
 */
function fphotography_test_for_min_php() {

	// Compare versions.
	if ( version_compare( PHP_VERSION, FPHOTOGRAPHY_MIN_PHP_VERSION, '<' ) ) {
		// Site doesn't meet themes min php requirements, add notice...
		add_action( 'admin_notices', 'fphotography_min_php_not_met_notice' );
		// ... and switch back to previous theme.
		switch_theme( get_option( 'theme_switched' ) );
		return false;

	};
}

if ( ! function_exists( 'wp_body_open' ) ) {
        function wp_body_open() {
                do_action( 'wp_body_open' );
        }
}

/**
 * An error notice that can be displayed if the Minimum PHP version is not met.
 */
function fphotography_min_php_not_met_notice() {
	?>
	<div class="notice notice-error is_dismissable">
		<p>
			<?php esc_html_e( 'You need to update your PHP version to run this theme.', 'fphotography' ); ?> <br />
			<?php
			printf(
				/* translators: 1 is the current PHP version string, 2 is the minmum supported php version string of the theme */
				esc_html__( 'Actual version is: %1$s, required version is: %2$s.', 'fphotography' ),
				PHP_VERSION,
				FPHOTOGRAPHY_MIN_PHP_VERSION
			); // phpcs: XSS ok.
			?>
		</p>
	</div>
	<?php
}


require_once( trailingslashit( get_template_directory() ) . 'customize-pro/class-customize.php' );

if ( ! function_exists( 'fphotography_setup' ) ) :
/**
 * fPhotography setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 */
function fphotography_setup() {

	load_theme_textdomain( 'fphotography', get_template_directory() . '/languages' );

	add_theme_support( "title-tag" );

	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	add_theme_support( 'editor-styles' );

	// add the visual editor to resemble the theme style
	add_editor_style( 'css/editor-style.css' );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary'   => __( 'Primary Menu', 'fphotography' ),
		'footer'    => __( 'Footer Menu', 'fphotography' ),
	) );

	// add Custom background				 
	add_theme_support( 'custom-background', 
				   array ('default-color'  => '#FFFFFF')
				 );


	add_theme_support( 'post-thumbnails' );


	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 900;

	add_theme_support( 'automatic-feed-links' );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form', 'comment-list',
	) );

	// add custom header
    add_theme_support( 'custom-header', array (
                       'default-image'          => '',
                       'random-default'         => '',
                       'flex-height'            => true,
                       'flex-width'             => true,
                       'uploads'                => true,
                       'width'                  => 900,
                       'height'                 => 100,
                       'default-text-color'        => '#000000',
                       'wp-head-callback'       => 'fphotography_header_style',
                    ) );

    // add custom logo
    add_theme_support( 'custom-logo', array (
                       'width'                  => 75,
                       'height'                 => 75,
                       'flex-height'            => true,
                       'flex-width'             => true,
                    ) );

    // Define and register starter content to showcase the theme on new sites.
	$starter_content = array(

		'widgets' => array(
			'sidebar-widget-area' => array(
				'search',
				'recent-posts',
				'categories',
				'archives',
			),

			'footer-column-1-widget-area' => array(
				'recent-comments'
			),

			'footer-column-2-widget-area' => array(
				'recent-posts'
			),

			'footer-column-3-widget-area' => array(
				'calendar'
			),
		),

		'posts' => array(
			'home',
			'blog',
			'about',
			'contact'
		),

		// Create the custom image attachments used as slides
		'attachments' => array(
			'image-slide-1' => array(
				'post_title' => _x( 'Slider Image 1', 'Theme starter content', 'fphotography' ),
				'file' => 'images/slider/1.jpg', // URL relative to the template directory.
			),
			'image-slide-2' => array(
				'post_title' => _x( 'Slider Image 2', 'Theme starter content', 'fphotography' ),
				'file' => 'images/slider/2.jpg', // URL relative to the template directory.
			),
			'image-slide-3' => array(
				'post_title' => _x( 'Slider Image 3', 'Theme starter content', 'fphotography' ),
				'file' => 'images/slider/3.jpg', // URL relative to the template directory.
			),
			'image-slide-4' => array(
				'post_title' => _x( 'Slider Image 4', 'Theme starter content', 'fphotography' ),
				'file' => 'images/slider/4.jpg', // URL relative to the template directory.
			),
			'image-slide-5' => array(
				'post_title' => _x( 'Slider Image 5', 'Theme starter content', 'fphotography' ),
				'file' => 'images/slider/5.jpg', // URL relative to the template directory.
			),
		),

		// Default to a static front page and assign the front and posts pages.
		'options' => array(
			'show_on_front' => 'page',
			'page_on_front' => '{{home}}',
			'page_for_posts' => '{{blog}}',
		),

		// Set the front page section theme mods to the IDs of the core-registered pages.
		'theme_mods' => array(
			'fphotography_slider_display' => 1,
			'fphotography_slide1_image' => '{{image-slider-1}}',
			'fphotography_slide1_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'Theme starter content', 'fphotography' ),
			'fphotography_slide2_image' => '{{image-slider-2}}',
			'fphotography_slide2_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'Theme starter content', 'fphotography' ),
			'fphotography_slide3_image' => '{{image-slider-3}}',
			'fphotography_slide3_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'Theme starter content', 'fphotography' ),
			'fphotography_slide4_image' => '{{image-slider-4}}',
			'fphotography_slide4_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'Theme starter content', 'fphotography' ),
			'fphotography_slide5_image' => '{{image-slider-5}}',
			'fphotography_slide5_content' => _x( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'Theme starter content', 'fphotography' ),
		),

		'nav_menus' => array(

			// Assign a menu to the "primary" location.
			'primary' => array(
				'name' => __( 'Primary Menu', 'fphotography' ),
				'items' => array(
					'link_home',
					'page_blog',
					'page_contact',
					'page_about',
				),
			),

			// Assign a menu to the "footer" location.
			'footer' => array(
				'name' => __( 'Footer Menu', 'fphotography' ),
				'items' => array(
					'link_home',
					'page_about',
					'page_blog',
					'page_contact',
				),
			),
		),
	);

	$starter_content = apply_filters( 'fphotography_starter_content', $starter_content );
	add_theme_support( 'starter-content', $starter_content );
}
endif; // fphotography_setup
add_action( 'after_setup_theme', 'fphotography_setup' );

/**
 * the main function to load scripts in the fPhotography theme
 * if you add a new load of script, style, etc. you can use that function
 * instead of adding a new wp_enqueue_scripts action for it.
 */
function fphotography_load_scripts() {

	// load main stylesheet.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array( ) );
	wp_enqueue_style( 'animate-css', get_template_directory_uri() . '/css/animate.css', array( ) );
	wp_enqueue_style( 'fphotography-style', get_stylesheet_uri(), array( ) );
	
	wp_enqueue_style( 'fphotography-fonts', fphotography_fonts_url(), array(), null );
	
	// Load thread comments reply script
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
	
	wp_enqueue_script( 'viewportchecker', get_template_directory_uri() . '/js/viewportchecker.js',
			array( 'jquery' ) );
	
	// Load Utilities JS Script
	wp_enqueue_script( 'fphotography-js', get_template_directory_uri() . '/js/utilities.js', array( 'jquery', 'viewportchecker' ) );
	
	$data = array(
		'loading_effect' => ( get_theme_mod('fphotography_animations_display', 1) == 1 ),
	);
	wp_localize_script('fphotography-js', 'fphotography_options', $data);

	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'classie', get_template_directory_uri() . '/js/classie.js', array( 'jquery' ) );
	wp_enqueue_script( 'photostack', get_template_directory_uri() . '/js/photostack.js', array( 'jquery' ) );
}

add_action( 'wp_enqueue_scripts', 'fphotography_load_scripts' );

/**
 *	Load google font url used in the fPhotography theme
 */
function fphotography_fonts_url() {

    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by Roboto, translate this to 'off'. Do not translate
    * into your own language.
    */
    $cantarell = _x( 'on', 'Roboto font: on or off', 'fphotography' );

    if ( 'off' !== $cantarell ) {
        $font_families = array();
 
        $font_families[] = 'Roboto';
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}

/**
 *	Used to load the content for posts and pages.
 */
function fphotography_the_content() {

	// Display Thumbnails if thumbnail is set for the post
	if ( has_post_thumbnail() ) {
?>

		<a href="<?php echo esc_url( get_permalink() ); ?>" title="<?php the_title_attribute(); ?>">
			<?php the_post_thumbnail(); ?>
		</a>
								
<?php
	}
	the_content( __( 'Read More', 'fphotography') );
}

/**
 * Display website's logo image
 */
function fphotography_show_website_logo_image_and_title() {

	if ( has_custom_logo() ) {

        the_custom_logo();
    }

    $header_text_color = get_header_textcolor();

    if ( 'blank' !== $header_text_color ) {
    
        echo '<div id="site-identity">';
        echo '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo('name') ) . '">';
        echo '<h1 class="entry-title">' . esc_html( get_bloginfo('name') ) . '</h1>';
        echo '</a>';
        echo '<strong>' . esc_html( get_bloginfo('description') ) . '</strong>';
        echo '</div>';
    }
}

/**
 *	Displays the copyright text.
 */
function fphotography_show_copyright_text() {

	$footerText = get_theme_mod('fphotography_footer_copyright', null);

	if ( !empty( $footerText ) ) {

		echo esc_html( $footerText ) . ' | ';		
	}
}

/**
 *	widgets-init action handler. Used to register widgets and register widget areas
 */
function fphotography_widgets_init() {
	
	// Register Sidebar Widget.
	register_sidebar( array (
						'name'	 		 =>	 __( 'Sidebar Widget Area', 'fphotography'),
						'id'		 	 =>	 'sidebar-widget-area',
						'description'	 =>  __( 'The sidebar widget area', 'fphotography'),
						'before_widget'	 =>  '',
						'after_widget'	 =>  '',
						'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
						'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
					) );

	// Register Footer Column #1
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #1', 'fphotography' ),
							'id' 			 =>  'footer-column-1-widget-area',
							'description'	 =>  __( 'The Footer Column #1 widget area', 'fphotography' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #2
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #2', 'fphotography' ),
							'id' 			 =>  'footer-column-2-widget-area',
							'description'	 =>  __( 'The Footer Column #2 widget area', 'fphotography' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #3
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #3', 'fphotography' ),
							'id' 			 =>  'footer-column-3-widget-area',
							'description'	 =>  __( 'The Footer Column #3 widget area', 'fphotography' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
}

add_action( 'widgets_init', 'fphotography_widgets_init' );

/**
 * Displays the slider
 */
function fphotography_display_slider() { ?>

	<div class="slider-container" id="slider-container">
		<section id="photostack" class="photostack">
			<div>
				<?php
					// display slides
					for ( $i = 1; $i <= 5; ++$i ) {
					
						$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
						$slideImage = get_theme_mod( 'fphotography_slide'.$i.'_image', $defaultSlideImage );

						if ( !empty($slideImage) ) :

							$slideContent = get_theme_mod( 'fphotography_slide'.$i.'_content' );	
							$imageAlt = sprintf( esc_html__( 'Image %s', 'fphotography' ), $i );
				?>

							<figure>
								<img src="<?php echo esc_url( $slideImage ); ?>" alt="<?php echo esc_attr( $imageAlt ); ?>" />
								<figcaption>
									<div class="photostack-back">
										<?php echo $slideContent; ?>									
									</div>
								</figcaption>
							</figure>


				<?php 	endif;

					} ?>
			</div>
		</section>
	</div><!-- #slider-container -->

<?php  
}

/**
 *	Displays the single content.
 */
function fphotography_the_content_single() {

	// Display Thumbnails if thumbnail is set for the post
	if ( has_post_thumbnail() ) {

		the_post_thumbnail();
	}
	the_content( __( 'Read More...', 'fphotography') );
}

/**
 * Register theme settings in the customizer
 */
function fphotography_customize_register( $wp_customize ) {
	
	/**
	 * Add Slider Section
	 */
	$wp_customize->add_section(
		'fphotography_slider_section',
		array(
			'title'       => __( 'Slider', 'fphotography' ),
			'capability'  => 'edit_theme_options',
		)
	);

	// Add display slider option
	$wp_customize->add_setting(
			'fphotography_slider_display',
			array(
					'default'           => 0,
					'sanitize_callback' => 'fphotography_sanitize_checkbox',
			)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slider_display',
							array(
								'label'          => __( 'Display Slider on a Static Front Page', 'fphotography' ),
								'section'        => 'fphotography_slider_section',
								'settings'       => 'fphotography_slider_display',
								'type'           => 'checkbox',
							)
						)
	);
	
	// Add slide 1 content
	$wp_customize->add_setting(
		'fphotography_slide1_content',
		array(
		    'sanitize_callback' => 'fphotography_sanitize_html',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slide1_content',
        array(
            'label'          => __( 'Slide #1 Content', 'fphotography' ),
            'section'        => 'fphotography_slider_section',
            'settings'       => 'fphotography_slide1_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add slide 1 background image
	$wp_customize->add_setting( 'fphotography_slide1_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '1.jpg',
    		'sanitize_callback' => 'fphotography_sanitize_url'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fphotography_slide1_image',
			array(
				'label'   	 => __( 'Slide 1 Image (Recommended Size: 240px x 240px)', 'fphotography' ),
				'section' 	 => 'fphotography_slider_section',
				'settings'   => 'fphotography_slide1_image',
			) 
		)
	);
	
	// Add slide 2 content
	$wp_customize->add_setting(
		'fphotography_slide2_content',
		array(
		    'sanitize_callback' => 'fphotography_sanitize_html',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slide2_content',
        array(
            'label'          => __( 'Slide #2 Content', 'fphotography' ),
            'section'        => 'fphotography_slider_section',
            'settings'       => 'fphotography_slide2_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add slide 2 background image
	$wp_customize->add_setting( 'fphotography_slide2_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '2.jpg',
    		'sanitize_callback' => 'fphotography_sanitize_url'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fphotography_slide2_image',
			array(
				'label'   	 => __( 'Slide 2 Image (Recommended Size: 240px x 240px)', 'fphotography' ),
				'section' 	 => 'fphotography_slider_section',
				'settings'   => 'fphotography_slide2_image',
			) 
		)
	);
	
	// Add slide 3 content
	$wp_customize->add_setting(
		'fphotography_slide3_content',
		array(
		    'sanitize_callback' => 'fphotography_sanitize_html',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slide3_content',
        array(
            'label'          => __( 'Slide #3 Content', 'fphotography' ),
            'section'        => 'fphotography_slider_section',
            'settings'       => 'fphotography_slide3_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add slide 3 background image
	$wp_customize->add_setting( 'fphotography_slide3_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '3.jpg',
    		'sanitize_callback' => 'fphotography_sanitize_url'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fphotography_slide3_image',
			array(
				'label'   	 => __( 'Slide 3 Image (Recommended Size: 240px x 240px)', 'fphotography' ),
				'section' 	 => 'fphotography_slider_section',
				'settings'   => 'fphotography_slide3_image',
			) 
		)
	);

	// Add slide 4 content
	$wp_customize->add_setting(
		'fphotography_slide4_content',
		array(
		    'sanitize_callback' => 'fphotography_sanitize_html',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slide4_content',
        array(
            'label'          => __( 'Slide #4 Content', 'fphotography' ),
            'section'        => 'fphotography_slider_section',
            'settings'       => 'fphotography_slide4_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add slide 4 background image
	$wp_customize->add_setting( 'fphotography_slide4_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '4.jpg',
    		'sanitize_callback' => 'fphotography_sanitize_url'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fphotography_slide4_image',
			array(
				'label'   	 => __( 'Slide 4 Image (Recommended Size: 240px x 240px)', 'fphotography' ),
				'section' 	 => 'fphotography_slider_section',
				'settings'   => 'fphotography_slide4_image',
			) 
		)
	);

	// Add slide 5 content
	$wp_customize->add_setting(
		'fphotography_slide5_content',
		array(
		    'sanitize_callback' => 'fphotography_sanitize_html',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_slide5_content',
        array(
            'label'          => __( 'Slide #5 Content', 'fphotography' ),
            'section'        => 'fphotography_slider_section',
            'settings'       => 'fphotography_slide5_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add slide 5 background image
	$wp_customize->add_setting( 'fphotography_slide5_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '5.jpg',
    		'sanitize_callback' => 'fphotography_sanitize_url'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fphotography_slide5_image',
			array(
				'label'   	 => __( 'Slide 5 Image (Recommended Size: 240px x 240px)', 'fphotography' ),
				'section' 	 => 'fphotography_slider_section',
				'settings'   => 'fphotography_slide5_image',
			) 
		)
	);

	/**
	 * Add Footer Section
	 */
	$wp_customize->add_section(
		'fphotography_footer_section',
		array(
			'title'       => __( 'Footer', 'fphotography' ),
			'capability'  => 'edit_theme_options',
		)
	);
	
	// Add footer copyright text
	$wp_customize->add_setting(
		'fphotography_footer_copyright',
		array(
		    'default'           => '',
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fphotography_footer_copyright',
        array(
            'label'          => __( 'Copyright Text', 'fphotography' ),
            'section'        => 'fphotography_footer_section',
            'settings'       => 'fphotography_footer_copyright',
            'type'           => 'text',
            )
        )
	);
	
	/**
	 * Add Animations Section
	 */
	$wp_customize->add_section(
		'fphotography_animations_display',
		array(
			'title'       => __( 'Animations', 'fphotography' ),
			'capability'  => 'edit_theme_options',
		)
	);

	// Add display Animations option
	$wp_customize->add_setting(
			'fphotography_animations_display',
			array(
					'default'           => 1,
					'sanitize_callback' => 'fphotography_sanitize_checkbox',
			)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize,
						'fphotography_animations_display',
							array(
								'label'          => __( 'Enable Animations', 'fphotography' ),
								'section'        => 'fphotography_animations_display',
								'settings'       => 'fphotography_animations_display',
								'type'           => 'checkbox',
							)
						)
	);
}

add_action('customize_register', 'fphotography_customize_register');

function fphotography_header_style() {

    $header_text_color = get_header_textcolor();

    if ( ! has_header_image()
        && ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color
             || 'blank' === $header_text_color ) ) {

        return;
    }

    $headerImage = get_header_image();
?>
    <style type="text/css">
        <?php if ( has_header_image() ) : ?>

                #header-main-fixed {background-image: url("<?php echo esc_url( $headerImage ); ?>");}

        <?php endif; ?>

        <?php if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color
                    && 'blank' !== $header_text_color ) : ?>

                #header-main-fixed, #header-main-fixed h1.entry-title {color: #<?php echo sanitize_hex_color_no_hash( $header_text_color ); ?>;}

        <?php endif; ?>
    </style>
<?php
}

if ( ! function_exists( 'fphotography_sanitize_checkbox' ) ) :
	/**
	 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
	 * as a boolean value, either TRUE or FALSE.
	 *
	 * @param bool $checked Whether the checkbox is checked.
	 * @return bool Whether the checkbox is checked.
	 */
	function fphotography_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
endif; // fphotography_sanitize_checkbox

if ( ! function_exists( 'fphotography_sanitize_html' ) ) :

	function fphotography_sanitize_html( $html ) {
		return wp_filter_post_kses( $html );
	}

endif; // fphotography_sanitize_html

if ( ! function_exists( 'fphotography_sanitize_url' ) ) :

	function fphotography_sanitize_url( $url ) {
		return esc_url_raw( $url );
	}

endif; // fphotography_sanitize_url

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function fphotography_skip_link_focus_fix() {
	// The following is minified via `terser --compress --mangle -- js/skip-link-focus-fix.js`.
	?>
	<script>
	/(trident|msie)/i.test(navigator.userAgent)&&document.getElementById&&window.addEventListener&&window.addEventListener("hashchange",function(){var t,e=location.hash.substring(1);/^[A-z0-9_-]+$/.test(e)&&(t=document.getElementById(e))&&(/^(?:a|select|input|button|textarea)$/i.test(t.tagName)||(t.tabIndex=-1),t.focus())},!1);
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'fphotography_skip_link_focus_fix' );

?>
